<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Account::Internal::AccountUserWidget</name>
    <message>
        <location filename="../../plugins/accountplugin/preferences/accountuseroptionspage.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/accountuseroptionspage.ui" line="32"/>
        <source>User preferences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Account::Internal::AccountView</name>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="20"/>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="26"/>
        <source>Start Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="33"/>
        <location filename="../../plugins/accountplugin/accountview.ui" line="47"/>
        <source>dd/MM/yyyy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="40"/>
        <source>End date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="55"/>
        <source>Show all accounts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="60"/>
        <source>Today&apos;s accounts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="65"/>
        <source>Yesterday&apos;s accounts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="70"/>
        <source>This week accounts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="75"/>
        <source>This month accounts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="80"/>
        <source>This year accounts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="104"/>
        <source>Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="110"/>
        <source>Cash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="124"/>
        <source>Cheque</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="138"/>
        <source>Visa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="152"/>
        <source>Du</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/accountview.ui" line="166"/>
        <source>Insurance</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Account::Internal::AvailableMovementWidget</name>
    <message>
        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.ui" line="32"/>
        <source>Available personnal movements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.ui" line="42"/>
        <source>Account details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.ui" line="48"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.ui" line="58"/>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.ui" line="68"/>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.ui" line="78"/>
        <source>Parent movement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.ui" line="127"/>
        <source>Available movement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="154"/>
        <source>Save changes ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="155"/>
        <source>You make changes into the bank account details.
Do you want to save them ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="159"/>
        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="188"/>
        <source>bank account details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="189"/>
        <source>Can not submit bank account details to your personnal database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="190"/>
        <source>An error occured during bank account details saving. Datas are corrupted.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Account::Internal::BankDetailsWidget</name>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.ui" line="32"/>
        <source>User&apos;s bank details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.ui" line="42"/>
        <source>Account details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.ui" line="48"/>
        <source>Owner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.ui" line="58"/>
        <source>Owner adress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.ui" line="68"/>
        <source>IBAN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.ui" line="78"/>
        <source>Bank account number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.ui" line="88"/>
        <source>Balance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.ui" line="98"/>
        <source>on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.ui" line="118"/>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.ui" line="128"/>
        <source>Use by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.ui" line="177"/>
        <source>Available bank account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="157"/>
        <source>Save changes ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="158"/>
        <source>You make changes into the bank account details.
Do you want to save them ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="162"/>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="191"/>
        <source>bank account details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="192"/>
        <source>Can not submit bank account details to your personnal database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="193"/>
        <source>An error occured during bank account details saving. Datas are corrupted.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Account::Internal::MedicalProcedureWidget</name>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="20"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="38"/>
        <source>Available personnal medical procedures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="48"/>
        <source>Account details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="54"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="67"/>
        <source>Abstract</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="80"/>
        <source>Owner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="90"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="103"/>
        <source>Amount</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="132"/>
        <source>User UUID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="139"/>
        <source>Reinbursment rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="152"/>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="173"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="208"/>
        <source>Medical 
Procedure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="178"/>
        <source>Save changes ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="179"/>
        <source>You make changes into the medical procedures table.
Do you want to save them ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="184"/>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="238"/>
        <source>medical_procedures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="239"/>
        <source>Can not submit medical procedure to your personnal database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="240"/>
        <source>An error occured during medical procedures saving. Datas are corrupted.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Account::Internal::VirtualDatabaseCreator</name>
    <message>
        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="32"/>
        <source>Virtual database creator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="95"/>
        <source>This widget will create a fake database and populate it with virtual datas.
This feature is usefull for testers and should not be used by current users.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="108"/>
        <source>Delete actual database (datas will be definitively lost)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="115"/>
        <source>Number of bank accounts to create</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="125"/>
        <source>Number of movements to create</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="135"/>
        <source>Number of medical procedures to create</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="145"/>
        <source>Number of accounts to create</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="211"/>
        <source>Create virtual database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.cpp" line="239"/>
        <source>Creating virtual database (%1 items to create)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.cpp" line="239"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Account::VirtualDatabaseCreatorPage</name>
    <message>
        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.cpp" line="173"/>
        <source>Virtual database creator</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
